# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

# NOTE(jamielennox): This directory is designed to reflect the dependency
# extras in the setup.cfg file. If you create an additional dependency section
# like 'kerberos' in the setup.cfg it is expected that there be a kerberos
# package here that can be imported.
#
# e.g. from keystoneauth1.extras import kerberos

pass
